from pwnic.config import has_game_started


class Attacker:
    def __init__(self) -> None:
        return

    def launch_attack(self, exploit: str, target: str) -> None:
        pass

    def launch_all_attacks(self) -> None:
        pass

    def update_targets(self) -> None:
        pass

    def update_exploits(self) -> None:
        pass
